/******************************************************************/
/* I/O Ports used by winchester disk controller. */
/******************************************************************

   -CS0   -CS1    HA2 HA1 HA0       IBM    T4    A5 A4 A3 A2
  -----------------------------------------------------------
     0      1      0   0   0       01F0   0020    1  0  0  0
     0      1      0   0   1       01F1   0024    1  0  0  1
     0      1      0   1   0       01F2   0028    1  0  1  0
     0      1      0   1   1       01F3   002C    1  0  1  1
     0      1      1   0   0       01F4   0030    1  1  0  0
     0      1      1   0   1       01F5   0034    1  1  0  1
     0      1      1   1   0       01F6   0038    1  1  1  0
     0      1      1   1   1       01F7   003C    1  1  1  1

     1      0      0   x   x
     1      0      1   0   x
     1      0      1   1   0       03F6   0018    0  1  1  0
     1      0      1   1   1       03F7   001C    0  1  1  1

 ******************************************************************/

#ifdef CONN1
/* primary */
#define WIN_REG1       0x1f0
#define WIN_REG2       0x1f1
#define WIN_REG3       0x1f2
#define WIN_REG4       0x1f3
#define WIN_REG5       0x1f4
#define WIN_REG6       0x1f5
#define WIN_REG7       0x1f6
#define WIN_REG8       0x1f7
#define WIN_REG9       0x3f6
#define WIN_REG10      0x3f7

#elif defined(CONN2)
/* secondary */
#define WIN_REG1       0x170
#define WIN_REG2       0x171
#define WIN_REG3       0x172
#define WIN_REG4       0x173
#define WIN_REG5       0x174
#define WIN_REG6       0x175
#define WIN_REG7       0x176
#define WIN_REG8       0x177
#define WIN_REG9       0x376
#define WIN_REG10      0x377

#else
#error 'Ndo' cazzo sta?
#endif

#define WIN_DATA	WIN_REG1    /* 01F0 RW	Data Register(8/16) */
#define WIN_ERR		WIN_REG2    /* 01F1 R=Error	W=Precomp   */
#define WIN_PCOMP	WIN_REG2
#define WIN_SC		WIN_REG3    /* 01F2 RW	Sector Count        */
#define WIN_SN		WIN_REG4    /* 01F3 RW	Sector Number       */
#define WIN_CYL		WIN_REG5    /* 01F4 RW	Cylinder low        */
#define WIN_CYH		WIN_REG6    /* 01F5 RW	Cylinder high       */
#define WIN_SDH		WIN_REG7    /* 01F6 RW	SDH Register        */
#define WIN_STAT	WIN_REG8    /* 01F7 R=Status	W=Command   */
#define WIN_COMM	WIN_REG8
#define WIN_ALT		WIN_REG9    /* 03F6 R=Status	W=Dig.Out   */
#define WIN_DOR		WIN_REG9
#define WIN_ADR		WIN_REG10   /* 03F7 R=Drive Address         */
/*------------------------------------------------------------------*/
/*
    WIN_ERR	0x24(0x1F1)
      b7                                 b0
      BBK  UNC  ---  IDNF ---  ABRT TKD  ---

    WIN_SDH	0x38(0x1F6)
      b7                                 b0
      RSVD.......... DRV  HEAD..............

    WIN_STAT	0x3C(0x1F7)
      b7                                 b0
      BSY  DRDY DWF  DSC  DRQ  CORR IDX  ERR

    WIN_ALT	0x18(0x3F6)
      b7                                 b0
      BSY  DRDY DWF  DSC  DRQ  CORR IDX  ERR
    WIN_DOR
      b7                                 b0
      ---  ---  ---  ---  ---  SRST -IEN ---

    WIN_ADR	0x1C(0x3F7)
      b7                                 b0
      RSVD -WTG -HS3 -HS2 -HS1 -HS0 -DS1 -DS0
 */
/*------------------------------------------------------------------*/
/* Winchester disk controller command bytes. */

#define WIN_RECALIBRATE	0x10	/* 0001xxxx	          D 	*/
#define WIN_READ        0x20	/* 001000lr	SC SN CY SDH	*/
#define WIN_WRITE       0x30	/* 001100lr	SC SN CY SDH	*/
#define WIN_READ_VERIFY	0x40	/* 0100000r	SC SN CY SDH	*/
#define WIN_FORMAT      0x50	/* 01010000	      CY SDH	*/
#define WIN_SEEK	0x70	/* 0111xxxx	      CY SDH	*/
#define WIN_DIAGNOSTIC	0x90	/* 10010000	         SDH	*/
#define WIN_SPECIFY     0x91	/* 10010001	         SDH	*/
#define WIN_READ_MULT	0xC4	/* 11000100	SC SN CY SDH	*/
#define WIN_WRITE_MULT	0xC5	/* 11000101	SC SN CY SDH	*/
#define WIN_SET_MULT	0xC6	/* 11000110	          D 	*/
#define WIN_READ_BUF	0xE4	/* 11100100	          D 	*/
#define WIN_WRITE_BUF	0xE8	/* 11100100	          D 	*/
#define WIN_IDENTIFY	0xEC	/* 11101100	          D 	*/
#define WIN_SETBUFMODE	0xEF	/* 11101111	          D 	*/
#define WIN_STANDBY	0xE0
#define WIN_IDLE	0xE1
#define WIN_PDOWNSTBY	0xE2
#define WIN_PDOWNIDLE	0xE3
#define WIN_GETPDMODE	0xE5
#define WIN_SLEEP	0xE6

/******************************************************************

Recalibrate	0001xxxx                 SD(H)
Read sectors	00100000	SC SN CY SDH	normal	retry
		001000x1				no retry
		0010001x			long
Write sectors	00110000	SC SN CY SDH	normal	retry
		001100x1				no retry
		0011001x			long
Read/verify	01000000			normal	retry
		01000001				no retry
Format track	01010000	      CY SDH
Seek		0111xxxx	      CY SDH
Diagnostic	10010000		 SDH
Initialize	10010001                 SDH
Read multiple	11000100	SC SN CY SDH
Write multiple	11000101	SC SN CY SDH
Set multiple	11000110	SC       SD(H)
Read buffer	11100100                 SD(H)
Write buffer	11101000                 SD(H)
Identify drive	11101100                 SD(H)
Set buff.mode	11101111                 SD(H)
Power comm.	1110pppp	SC       SD(H)

******************************************************************/

/* Parameters for the disk drive. */
#define SECTOR_SIZE      512	/* physical sector size in bytes */

/******************************************************************/

